@@ -1,7 +1,7 @@
 // Copyright 2020-2022 PANDA GmbH
 
-#ifndef SRC_DENOISE_H_
-#define SRC_DENOISE_H_
+#ifndef PYTHON_SRC_DENOISE_H_
+#define PYTHON_SRC_DENOISE_H_
 
 #include <pybind11/pybind11.h>
 
@@ -9,4 +9,4 @@ namespace py = pybind11;
 
 void WrapDenoiseAlgorithms(py::module *m);
 
-#endif  // SRC_DENOISE_H_
+#endif  // PYTHON_SRC_DENOISE_H_
