@@ -1,7 +1,7 @@
 // Copyright 2022 PANDA GmbH
 
-#ifndef SRC_WAVELET_BUFFER_H_
-#define SRC_WAVELET_BUFFER_H_
+#ifndef PYTHON_SRC_WAVELET_BUFFER_H_
+#define PYTHON_SRC_WAVELET_BUFFER_H_
 
 #include <pybind11/pybind11.h>
 
@@ -9,4 +9,4 @@ namespace py = pybind11;
 
 void WrapWaveletBuffer(py::module *m);
 
-#endif  // SRC_WAVELET_BUFFER_H_
+#endif  // PYTHON_SRC_WAVELET_BUFFER_H_
